<?php
/**
 * @version		1.0.0
 * @package		Joomla
 * @subpackage	EDocman
 * @author  Tuan Pham Ngoc
 * @copyright	Copyright (C) 2010 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */
defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');
jimport('joomla.html.parameter') ;

/**
 * EDocman Search plugin
 *
 * @package		Joomla
 * @subpackage	EDocman
 * @since		1.6
 */
class plgSearchEDocman extends JPlugin
{
	/**
	 * Constructor
	 *
	 * @access      protected
	 * @param       object  $subject The object to observe
	 * @param       array   $config  An array that holds the plugin configuration
	 * @since       1.5
	 */
	public function __construct(& $subject, $config)
	{
		parent::__construct($subject, $config);
		$this->loadLanguage();
	}

	/**
	* @return array An array of search areas
	*/
	function onContentSearchAreas()
	{
		static $areas = array(
			'edocman_search' => 'Documents'
		);
		return $areas;
	}

	function onContentSearch($text, $phrase='', $ordering='', $areas=null)
	{
		require_once JPATH_ADMINISTRATOR.'/components/com_edocman/helpers/edocman.php';
        require_once JPATH_ROOT.'/components/com_edocman/helper/route.php';
		$db		= JFactory::getDBO();
		$Itemid = EdocmanHelper::getItemid();
		EdocmanHelper::loadLanguage() ;		
		if (is_array( $areas )) {
			if (!array_intersect( $areas, array_keys($this->onContentSearchAreas()) )) {
				return array();
			}
		}
		// load plugin params info	 	
	 	$pluginParams = $this->params ;
		$limit = $pluginParams->def( 'search_limit', 50 );
		$text = trim( $text );
		if ($text == '') {
			return array();
		}
		$section 	= JText::_( 'EDOCMAN_DOCUMENTS' );
		$wheres 	= array();		
		switch ($phrase)
		{
			case 'exact':
				$text		= $db->Quote( '%'.$db->escape( $text, true ).'%', false );
				$wheres2 	= array();
				$wheres2[] 	= 'a.title LIKE '.$text;
				$wheres2[] 	= 'a.short_description LIKE '.$text;
				$wheres2[] 	= 'a.description LIKE '.$text;						
				$wheres2[] 	= 'a.indexed_content LIKE '.$text;
				$where 		= '(' . implode( ') OR (', $wheres2 ) . ')';
				break;
	
			case 'all':
			case 'any':
			default:
				$words 	= explode( ' ', $text );
				$wheres = array();
				foreach ($words as $word)
				{
					$word		= $db->Quote( '%'.$db->escape( $word, true ).'%', false );
					$wheres2 	= array();
					$wheres2[] 	= 'a.title LIKE '.$word;
					$wheres2[] 	= 'a.short_description LIKE '.$word;
					$wheres2[] 	= 'a.description LIKE '.$word;		
					$wheres2[] 	= 'a.indexed_content LIKE '.$word;
					$wheres[] 	= implode( ' OR ', $wheres2 );
				}
				$where 	= '(' . implode( ($phrase == 'all' ? ') AND (' : ') OR ('), $wheres ) . ')';
				break;
		}
	
		switch ( $ordering )
		{
			case 'oldest':
				$order = 'a.created_time ASC';
				break;		
			case 'alpha':
				$order = 'a.title ASC';
				break;
			case 'newest':
				$order = 'a.created_time DESC';
                break;
			default:
				$order = 'a.ordering ';
		}	
		$user = JFactory::getUser() ;
		$query = 'SELECT a.id, 0 AS cat_id, a.title AS title, a.short_description, a.description AS text, created_time AS `created`, '
		.$db->Quote($section) .' AS section,'
		. ' "1" AS browsernav'
		. ' FROM #__edocman_documents AS a'	
		. ' WHERE ('. $where .') AND a.access IN ('.implode(',', $user->getAuthorisedViewLevels()).')'
		. ' AND a.published = 1'	
		. ' ORDER BY '. $order
		;
		$db->setQuery( $query, 0, $limit );			
		$rows = $db->loadObjectList();
		if (count($rows)) {
			foreach($rows as $key => $row)
            {
            	if ($user->authorise('edocman.download', 'com_edocman.document.'.$row->id))
            	{
            		$rows[$key]->href = JRoute::_(JRoute::_('index.php?option=com_edocman&task=document.viewdoc&id='.$row->id.'&Itemid='.$Itemid) );
            	}
            	else 
            	{
            		$rows[$key]->href = JRoute::_(EDocmanHelperRoute::getDocumentRoute($row->id, 0, $Itemid));
            	}
                
                if (!strlen(strip_tags($rows[$key]->text)))
                {
                    $rows[$key]->text = $rows[$key]->short_description;
                }
			}	
		}	
		return $rows ;
	}	
}
